Module: Google::Cloud::Dataproc
- Defined in:
- lib/google/cloud/dataproc.rb,
lib/google/cloud/dataproc/version.rb
Constant Summary collapse
- VERSION =
"2.2.0"
Class Method Summary collapse
-
.autoscaling_policy_service(version: :v1, &block) ⇒ ::Object
Create a new client object for AutoscalingPolicyService.
-
.batch_controller(version: :v1, &block) ⇒ ::Object
Create a new client object for BatchController.
-
.cluster_controller(version: :v1, &block) ⇒ ::Object
Create a new client object for ClusterController.
-
.configure {|::Google::Cloud.configure.dataproc| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-dataproc library.
-
.job_controller(version: :v1, &block) ⇒ ::Object
Create a new client object for JobController.
-
.node_group_controller(version: :v1, &block) ⇒ ::Object
Create a new client object for NodeGroupController.
-
.workflow_template_service(version: :v1, &block) ⇒ ::Object
Create a new client object for WorkflowTemplateService.
Class Method Details
.autoscaling_policy_service(version: :v1, &block) ⇒ ::Object
Create a new client object for AutoscalingPolicyService.
By default, this returns an instance of
Google::Cloud::Dataproc::V1::AutoscalingPolicyService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the AutoscalingPolicyService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About AutoscalingPolicyService
The API interface for managing autoscaling policies in the Dataproc API.
67 68 69 70 71 72 73 74 75 76 |
# File 'lib/google/cloud/dataproc.rb', line 67 def self.autoscaling_policy_service version: :v1, &block require "google/cloud/dataproc/#{version.to_s.downcase}" package_name = Google::Cloud::Dataproc .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataproc.const_get(package_name).const_get(:AutoscalingPolicyService) service_module.const_get(:Client).new(&block) end |
.batch_controller(version: :v1, &block) ⇒ ::Object
Create a new client object for BatchController.
By default, this returns an instance of
Google::Cloud::Dataproc::V1::BatchController::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the BatchController service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About BatchController
The BatchController provides methods to manage batch workloads.
97 98 99 100 101 102 103 104 105 106 |
# File 'lib/google/cloud/dataproc.rb', line 97 def self.batch_controller version: :v1, &block require "google/cloud/dataproc/#{version.to_s.downcase}" package_name = Google::Cloud::Dataproc .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataproc.const_get(package_name).const_get(:BatchController) service_module.const_get(:Client).new(&block) end |
.cluster_controller(version: :v1, &block) ⇒ ::Object
Create a new client object for ClusterController.
By default, this returns an instance of
Google::Cloud::Dataproc::V1::ClusterController::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ClusterController service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About ClusterController
The ClusterControllerService provides methods to manage clusters of Compute Engine instances.
128 129 130 131 132 133 134 135 136 137 |
# File 'lib/google/cloud/dataproc.rb', line 128 def self.cluster_controller version: :v1, &block require "google/cloud/dataproc/#{version.to_s.downcase}" package_name = Google::Cloud::Dataproc .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataproc.const_get(package_name).const_get(:ClusterController) service_module.const_get(:Client).new(&block) end |
.configure {|::Google::Cloud.configure.dataproc| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-dataproc library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
259 260 261 262 263 |
# File 'lib/google/cloud/dataproc.rb', line 259 def self.configure yield ::Google::Cloud.configure.dataproc if block_given? ::Google::Cloud.configure.dataproc end |
.job_controller(version: :v1, &block) ⇒ ::Object
Create a new client object for JobController.
By default, this returns an instance of
Google::Cloud::Dataproc::V1::JobController::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the JobController service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About JobController
The JobController provides methods to manage jobs.
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/google/cloud/dataproc.rb', line 158 def self.job_controller version: :v1, &block require "google/cloud/dataproc/#{version.to_s.downcase}" package_name = Google::Cloud::Dataproc .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataproc.const_get(package_name).const_get(:JobController) service_module.const_get(:Client).new(&block) end |
.node_group_controller(version: :v1, &block) ⇒ ::Object
Create a new client object for NodeGroupController.
By default, this returns an instance of
Google::Cloud::Dataproc::V1::NodeGroupController::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the NodeGroupController service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About NodeGroupController
The NodeGroupControllerService provides methods to manage node groups
of Compute Engine managed instances.
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/google/cloud/dataproc.rb', line 220 def self.node_group_controller version: :v1, &block require "google/cloud/dataproc/#{version.to_s.downcase}" package_name = Google::Cloud::Dataproc .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataproc.const_get(package_name).const_get(:NodeGroupController) service_module.const_get(:Client).new(&block) end |
.workflow_template_service(version: :v1, &block) ⇒ ::Object
Create a new client object for WorkflowTemplateService.
By default, this returns an instance of
Google::Cloud::Dataproc::V1::WorkflowTemplateService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the WorkflowTemplateService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About WorkflowTemplateService
The API interface for managing Workflow Templates in the Dataproc API.
189 190 191 192 193 194 195 196 197 198 |
# File 'lib/google/cloud/dataproc.rb', line 189 def self.workflow_template_service version: :v1, &block require "google/cloud/dataproc/#{version.to_s.downcase}" package_name = Google::Cloud::Dataproc .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Dataproc.const_get(package_name).const_get(:WorkflowTemplateService) service_module.const_get(:Client).new(&block) end |